@@ -107,7 +107,7 @@ async def detect_frameworks_async(project_path: Path) -> DetectionResult:
                 scores[detector.name] = 0
         
         # Determine final result
-        detected_framework = detected_framework or "na"
+        detected_framework = detected_framework or ""
         detected_name = framework_names.get(detected_framework, "Unknown")
         
         result = DetectionResult(
@@ -156,7 +156,7 @@ def display_results(result: DetectionResult, show_all: bool = False, json_output
     framework_names = FrameworkDetectorFactory.get_framework_names()
     
     for code, name in framework_names.items():
-        if code == "na":
+        if code == "":
             continue
             
         score = result.scores.get(code, 0)
@@ -176,13 +176,13 @@ def display_results(result: DetectionResult, show_all: bool = False, json_output
     console.print(table)
     
     # Display final result
-    status_style = "bold green" if result.detected_framework != "na" else "bold yellow"
+    status_style = "bold green" if result.detected_framework != "" else "bold yellow"
     result_text = Text(f"{result.detected_name} ({result.detected_framework})", style=status_style)
     
     panel = Panel(
         result_text,
         title="Detection Result",
-        border_style="green" if result.detected_framework != "na" else "yellow"
+        border_style="green" if result.detected_framework != "" else "yellow"
     )
     console.print(panel)
 
